/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.cloudfarming.client.field.type;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import nl.cloudfarming.client.field.model.Field;
import nl.cloudfarming.client.field.model.FieldManager;
import org.openide.filesystems.FileObject;
import org.openide.util.Exceptions;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Timon Veenstra
 */
@ServiceProvider(service=FieldManager.class)
public class FieldManagerImpl implements FieldManager{

    /**
     * Load a Field from a file object
     *
     * @param fileObject
     * @return
     */
    @Override
    public Field load(FileObject fileObject) {
        Field field = null;
        try (ObjectInputStream ois = new ObjectInputStream(fileObject.getInputStream())) {
            field = (Field) ois.readObject();
        } catch (ClassNotFoundException | IOException ex) {
            Exceptions.printStackTrace(ex);
        }
        return field;
    }

    /**
     *
     * @param field
     * @param fileObject
     */
    @Override
    public void save(Field field, FileObject fileObject) {
        try (ObjectOutputStream oos = new ObjectOutputStream(fileObject.getOutputStream())) {
            oos.writeObject(field);
        } catch (IOException ex) {
            Exceptions.printStackTrace(ex);
        }

    }


}
